==> lintian_2.89.0.tar.xz: lintian-2.89.0/checks/fields/terminal-control.pm <==
# fields/terminal-control -- lintian check script -*- perl -*-
#
# Copyright © 2020 Felix Lechner
#
# Parts of the code were taken from the old check script, which
# was Copyright © 1998 Richard Braakman (also licensed under the
# GPL 2 or higher)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::fields::terminal_control;

use v5.20;
use warnings;
use utf8;
use autodie;

use constant ESCAPE => qq{\033};

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub always {
    my ($self) = @_;

    my @names = $self->processable->fields->names;

    # fields that contain ESC characters
    my @escaped
      = grep { index($self->processable->fields->value($_), ESCAPE) >= 0 }
      @names;

    $self->tag('ansi-escape', $_, $self->processable->fields->value($_))
      for @escaped;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et

==> lintian_2.104.0.tar.xz: lintian-2.104.0/checks/fields/terminal-control.pm <==
# fields/terminal-control -- lintian check script -*- perl -*-
#
# Copyright © 2020 Felix Lechner
#
# Parts of the code were taken from the old check script, which
# was Copyright © 1998 Richard Braakman (also licensed under the
# GPL 2 or higher)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::fields::terminal_control;

use v5.20;
use warnings;
use utf8;
use autodie;

use constant ESCAPE => qq{\033};

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub always {
    my ($self) = @_;

    my @names = $self->processable->fields->names;

    # fields that contain ESC characters
    my @escaped
      = grep { index($self->processable->fields->value($_), ESCAPE) >= 0 }
      @names;

    $self->hint('ansi-escape', $_, $self->processable->fields->value($_))
      for @escaped;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
